@@ -128,6 +128,7 @@ ConfigPanelWidget::ConfigPanelWidget(UKUIPanel *panel, QWidget *parent) :
     gsettings= new QGSettings("org.mate.interface", "", this);
     connect(gsettings,&QGSettings::changed,this,&ConfigPanelWidget::reset);
 
+
 }
 
 
@@ -137,19 +138,19 @@ ConfigPanelWidget::ConfigPanelWidget(UKUIPanel *panel, QWidget *parent) :
 void ConfigPanelWidget::reset()
 {
     QStringList sheet;
-    QGSettings *gsettings;
-    gsettings= new QGSettings("org.mate.interface", "", this);
-    QString mode;
-    mode=gsettings->get("gtk-theme").toString();
-    qDebug()<<"ukui-theme:"<<mode;
-    if(mode=="ukui-blue")
-    {
-        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
-    }
-    else
-    {
+//    QGSettings *gsettings;
+//    gsettings= new QGSettings("org.mate.interface", "", this);
+//    QString mode;
+//    mode=gsettings->get("gtk-theme").toString();
+//    qDebug()<<"ukui-theme:"<<mode;
+//    if(mode=="ukui-blue")
+//    {
+//        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
+//    }
+//    else
+//    {
         sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(19,22,28,90%); }");
-    }
+//    }
     setStyleSheet(sheet.join("\n"));
     ui->spinBox_panelSize->setValue(mOldPanelSize);
     ui->spinBox_iconSize->setValue(mOldIconSize);
@@ -335,19 +336,19 @@ ConfigPanelWidget::~ConfigPanelWidget()
 void ConfigPanelWidget::editChanged()
 {
     QStringList sheet;
-    QGSettings *gsettings;
-    gsettings= new QGSettings("org.mate.interface", "", this);
-    QString mode;
-    mode=gsettings->get("gtk-theme").toString();
-    qDebug()<<"ukui-theme:"<<mode;
-    if(mode=="ukui-blue")
-    {
-        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
-    }
-    else
-    {
+//    QGSettings *gsettings;
+//    gsettings= new QGSettings("org.mate.interface", "", this);
+//    QString mode;
+//    mode=gsettings->get("gtk-theme").toString();
+//    qDebug()<<"ukui-theme:"<<mode;
+//    if(mode=="ukui-blue")
+//    {
+//        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
+//    }
+//    else
+//    {
         sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(19,22,28,90%); }");
-    }
+//    }
     setStyleSheet(sheet.join("\n"));
     mPanel->setPanelSize(ui->spinBox_panelSize->value(), true);
     mPanel->setIconSize(ui->spinBox_iconSize->value(), true);
@@ -513,65 +514,282 @@ void ConfigPanelWidget::pickBackgroundImage()
 }
 
 void ConfigPanelWidget::positionChanged_top()
-{    mPosition   =IUKUIPanel::PositionTop;
-     editChanged();
+{    
+    mPosition   =IUKUIPanel::PositionTop;
+    editChanged();
+    mOldScreenNum = mScreenNum;
+    mOldPosition = mPosition;
+    QDBusMessage message = QDBusMessage::createMethodCall("com.ukui.panel.sidebar",
+			         "/getvalue/panel",
+			         "com.ukui.panel.sidebar.value",
+			         "panelPositionChangeNotify");
+
+    uint position=mPosition;
+    message << position;
+    QDBusConnection::sessionBus().send(message);
+
+    QDBusMessage menuMessage = QDBusMessage::createMethodCall("com.ukui.panel.menu",
+			          "/getvalue/panel",
+			          "com.ukui.panel.sidebar.value",
+			          "panelPositionChangeNotify");
+
+    menuMessage << position;
+    QDBusConnection::sessionBus().send(menuMessage);
 }
 void ConfigPanelWidget::positionChanged_bottom()
 {    mPosition   =IUKUIPanel::PositionBottom;
      editChanged();
+    mOldScreenNum = mScreenNum;
+    mOldPosition = mPosition;
+     QDBusMessage message = QDBusMessage::createMethodCall("com.ukui.panel.sidebar",
+                                "/getvalue/panel",
+                                "com.ukui.panel.sidebar.value",
+                                "panelPositionChangeNotify");
+
+     uint position=mPosition;
+     message << position;
+     QDBusConnection::sessionBus().send(message);
+
+      QDBusMessage menuMessage = QDBusMessage::createMethodCall("com.ukui.panel.menu",
+                                 "/getvalue/panel",
+                                 "com.ukui.panel.sidebar.value",
+                                 "panelPositionChangeNotify");
+
+      menuMessage << position;
+      QDBusConnection::sessionBus().send(menuMessage);
 }
 
 void ConfigPanelWidget::positionChanged_left()
 {    mPosition   =IUKUIPanel::PositionLeft;
      editChanged();
+    mOldScreenNum = mScreenNum;
+    mOldPosition = mPosition;
+      QDBusMessage message = QDBusMessage::createMethodCall("com.ukui.panel.sidebar",
+                                 "/getvalue/panel",
+                                 "com.ukui.panel.sidebar.value",
+                                 "panelPositionChangeNotify");
+
+      uint position=mPosition;
+      message << position;
+      QDBusConnection::sessionBus().send(message);
+
+       QDBusMessage menuMessage = QDBusMessage::createMethodCall("com.ukui.panel.menu",
+                                  "/getvalue/panel",
+                                  "com.ukui.panel.sidebar.value",
+                                  "panelPositionChangeNotify");
+
+       menuMessage << position;
+       QDBusConnection::sessionBus().send(menuMessage);
 }
 
 void ConfigPanelWidget::positionChanged_right()
 {    mPosition   =IUKUIPanel::PositionRight;
      editChanged();
+    mOldScreenNum = mScreenNum;
+    mOldPosition = mPosition;
+      QDBusMessage message = QDBusMessage::createMethodCall("com.ukui.panel.sidebar",
+                                 "/getvalue/panel",
+                                 "com.ukui.panel.sidebar.value",
+                                 "panelPositionChangeNotify");
+
+      uint position=mPosition;
+      message << position;
+      QDBusConnection::sessionBus().send(message);
+
+       QDBusMessage menuMessage = QDBusMessage::createMethodCall("com.ukui.panel.menu",
+                                  "/getvalue/panel",
+                                  "com.ukui.panel.sidebar.value",
+                                  "panelPositionChangeNotify");
+
+       menuMessage << position;
+       QDBusConnection::sessionBus().send(menuMessage);
 }
 
 void ConfigPanelWidget::changeToSmallSize()
 {
     mOldPanelSize = 46;
-    mOldIconSize  = 24;
+    mOldIconSize  = 32;
     editChanged();
+    QDBusMessage message = QDBusMessage::createMethodCall("com.ukui.panel.sidebar",
+                              "/getvalue/panel",
+                              "com.ukui.panel.sidebar.value",
+                              "panelSizeChangeNotify");
+
+    message << mOldPanelSize;
+    QDBusConnection::sessionBus().send(message);
+
+    QDBusMessage menuMessage = QDBusMessage::createMethodCall("com.ukui.panel.menu",
+                              "/getvalue/panel",
+                              "com.ukui.panel.sidebar.value",
+                              "panelSizeChangeNotify");
+
+    menuMessage << mOldPanelSize;
+    QDBusConnection::sessionBus().send(menuMessage);
     reset();
 }
 
 void ConfigPanelWidget::changeToMidSize()
 {
     mOldPanelSize = 72;
-    mOldIconSize = 36;
+    mOldIconSize = 48;
     editChanged();
+    QDBusMessage message = QDBusMessage::createMethodCall("com.ukui.panel.sidebar",
+                              "/getvalue/panel",
+                              "com.ukui.panel.sidebar.value",
+                              "panelSizeChangeNotify");
+
+    message << mOldPanelSize;
+    QDBusConnection::sessionBus().send(message);
+
     reset();
 }
 
 void ConfigPanelWidget::changeToLargeSize()
 {
     mOldPanelSize = 94;
-    mOldIconSize = 48;
+    mOldIconSize = 64;
     editChanged();
+    QDBusMessage message = QDBusMessage::createMethodCall("com.ukui.panel.sidebar",
+                              "/getvalue/panel",
+                              "com.ukui.panel.sidebar.value",
+                              "panelSizeChangeNotify");
+
+    message << mOldPanelSize;
+    QDBusConnection::sessionBus().send(message);
+
+    QDBusMessage menuMessage = QDBusMessage::createMethodCall("com.ukui.panel.menu",
+                              "/getvalue/panel",
+                              "com.ukui.panel.sidebar.value",
+                              "panelSizeChangeNotify");
+
+    menuMessage << mOldPanelSize;
+    QDBusConnection::sessionBus().send(menuMessage);
     reset();
 }
 
 void ConfigPanelWidget::changeBackground()
 {
     QStringList sheet;
-    QGSettings *gsettings;
-    gsettings= new QGSettings("org.mate.interface", "", this);
-    QString mode;
-    mode=gsettings->get("gtk-theme").toString();
-    qDebug()<<"ukui-theme:"<<mode;
-    if(mode=="ukui-blue")
-    {
-        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
-    }
-    else
-    {
+//    QGSettings *gsettings;
+//    gsettings= new QGSettings("org.mate.interface", "", this);
+//    QString mode;
+//    mode=gsettings->get("gtk-theme").toString();
+//    qDebug()<<"ukui-theme:"<<mode;
+//    if(mode=="ukui-blue")
+//    {
+//        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
+//    }
+//    else
+//    {
         sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(19,22,28,90%); }");
-    }
+//    }
     setStyleSheet(sheet.join("\n"));
     editChanged();
     reset();
 }
+
+bool ConfigPanelWidget::SetPanelsizeSmall(QString arg)
+{
+    changeToSmallSize();
+    return true;
+}
+
+bool ConfigPanelWidget::SetPanelsizeMid(QString arg)
+{
+    changeToMidSize();
+    return true;
+}
+
+bool ConfigPanelWidget::SetPanelsizeLarge(QString arg)
+{
+    changeToLargeSize();
+    qDebug()<<"setPanelSizeLarge";
+    return true;
+}
+
+bool ConfigPanelWidget::SetPanelPositionLeft(QString arg)
+{
+    positionChanged_left();
+    return true;
+}
+
+bool ConfigPanelWidget::SetPanelPositionRight(QString arg)
+{
+    positionChanged_right();
+    return true;
+}
+
+bool ConfigPanelWidget::SetPanelPositionUp(QString arg)
+{
+    positionChanged_top();
+    return true;
+}
+
+bool ConfigPanelWidget::SetPanelPositionBottom(QString arg)
+{
+    positionChanged_bottom();
+    return true;
+}
+/*
+ * Implementation of adaptor class FilectrlAdaptor
+ */
+
+FileSetPanel::FileSetPanel(QObject *parent)
+    : QDBusAbstractAdaptor(parent)
+{
+    // constructor
+    setAutoRelaySignals(true);
+}
+
+FileSetPanel::~FileSetPanel()
+{
+    // destructor
+}
+bool FileSetPanel::SetPanelsizeSmall(const QString &arg)
+{
+    bool out0;
+    QMetaObject::invokeMethod(parent(), "SetPanelsizeSmall", Q_RETURN_ARG(bool, out0), Q_ARG(QString, arg));
+    return out0;
+}
+
+bool FileSetPanel::SetPanelsizeMid(const QString &arg)
+{
+    bool out0;
+    QMetaObject::invokeMethod(parent(), "SetPanelsizeMid", Q_RETURN_ARG(bool, out0), Q_ARG(QString, arg));
+    return out0;
+}
+
+bool FileSetPanel::SetPanelsizeLarge(const QString &arg)
+{
+    bool out0;
+    QMetaObject::invokeMethod(parent(), "SetPanelsizeLarge", Q_RETURN_ARG(bool, out0), Q_ARG(QString, arg));
+    return out0;
+}
+
+bool FileSetPanel::SetPanelPositionLeft(const QString &arg)
+{
+    bool out0;
+    QMetaObject::invokeMethod(parent(), "SetPanelPositionLeft", Q_RETURN_ARG(bool, out0), Q_ARG(QString, arg));
+    return out0;
+}
+
+bool FileSetPanel::SetPanelPositionRight(const QString &arg)
+{
+    bool out0;
+    QMetaObject::invokeMethod(parent(), "SetPanelPositionRight", Q_RETURN_ARG(bool, out0), Q_ARG(QString, arg));
+    return out0;
+}
+
+bool FileSetPanel::SetPanelPositionUp(const QString &arg)
+{
+    bool out0;
+    QMetaObject::invokeMethod(parent(), "SetPanelPositionUp", Q_RETURN_ARG(bool, out0), Q_ARG(QString, arg));
+    return out0;
+}
+
+bool FileSetPanel::SetPanelPositionBottom(const QString &arg)
+{
+    bool out0;
+    QMetaObject::invokeMethod(parent(), "SetPanelPositionBottom", Q_RETURN_ARG(bool, out0), Q_ARG(QString, arg));
+    return out0;
+}
