@@ -81,9 +81,21 @@
 #define CFG_KEY_SHOW_DELAY         "show-delay"
 #define CFG_KEY_LOCKPANEL          "lockPanel"
 
-
 #define GSETTINGS_SCHEMA_SCREENSAVER "org.mate.interface"
 #define KEY_MODE "gtk-theme"
+
+#define PANEL_SIZE_LARGE  92
+#define PANEL_SIZE_MEDIUM 70
+#define PANEL_SIZE_SMALL  46
+#define ICON_SIZE_LARGE   64
+#define ICON_SIZE_MEDIUM  48
+#define ICON_SIZE_SMALL   32
+
+#define PANEL_SETTINGS "org.ukui.panel.settings"
+#define PANEL_SIZE_KEY "panelsize"
+#define ICON_SIZE_KEY "iconsize"
+#define PANEL_POSITION_KEY "panelposition"
+
 /************************************************
  Returns the Position by the string.
  String is one of "Top", "Left", "Bottom", "Right", string is not case sensitive.
@@ -232,7 +244,10 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
         showPanel(false);
         QTimer::singleShot(PANEL_HIDE_FIRST_TIME, this, SLOT(hidePanel()));
     }
-   // mConfigDialog=new ConfigPanelDialog(this);
+    UKUIPanelApplication *a = reinterpret_cast<UKUIPanelApplication*>(qApp);
+    connect(a, &UKUIPanelApplication::primaryScreenChanged, this, &UKUIPanel::setPanelGeometry);
+    const QByteArray id(PANEL_SETTINGS);
+    gsettings = new QGSettings(id);
 }
 
 /************************************************
@@ -417,9 +432,15 @@ int UKUIPanel::getReserveDimension()
     return mHidable ? PANEL_HIDE_SIZE : qMax(PANEL_MINIMUM_SIZE, mPanelSize);
 }
 
+/*
+ The setting frame of the old panel does not follow the main screen
+ but can be displayed on any screen
+ but the current desktop environment of ukui is set to follow the main screen
+ All default parameters desktop()->screenGeometry are 0
+ */
 void UKUIPanel::setPanelGeometry(bool animate)
 {
-    const QRect currentScreen = QApplication::desktop()->screenGeometry(mActualScreenNum);
+    const QRect currentScreen = QApplication::desktop()->screenGeometry(0);
     QRect rect;
 
     if (isHorizontal())
@@ -577,19 +598,19 @@ void UKUIPanel::setMargins()
 void UKUIPanel::realign()
 {
     QStringList sheet;
-    QGSettings *gsettings;
-    gsettings= new QGSettings("org.mate.interface", "", this);
-    QString mode;
-    mode=gsettings->get("gtk-theme").toString();
-    qDebug()<<"ukui-theme:"<<mode;
-    if(mode=="ukui-blue")
-    {
-        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
-    }
-    else
-    {
+//    QGSettings *gsettings;
+//    gsettings= new QGSettings("org.mate.interface", "", this);
+//    QString mode;
+//    mode=gsettings->get("gtk-theme").toString();
+//    qDebug()<<"ukui-theme:"<<mode;
+//    if(mode=="ukui-blue")
+//    {
+//        sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(230,232,235,90%); }");
+//    }
+//    else
+//    {
         sheet << QString("UKUIPanel #BackgroundWidget { background-color: rgba(19,22,28,90%); }");
-    }
+//    }
     setStyleSheet(sheet.join("\n"));
     if (!isVisible())
         return;
@@ -795,7 +816,13 @@ void UKUIPanel::setPanelStyle()
 
 void UKUIPanel::systeMonitor()
 {
-    system("mate-system-monitor");
+//    system("mate-system-monitor");
+    if(QFileInfo::exists(QString("/usr/bin/mate-system-monitor")))
+    {
+    QProcess *process =new QProcess(this);
+    process->startDetached("/usr/bin/mate-system-monitor");
+    }
+    else{qDebug()<<"not find /usr/bin/mate-system-monitor"<<endl;}
 }
 #include <KWindowSystem/KWindowSystem>
 #include <KWindowSystem/NETWM>
@@ -1151,29 +1178,6 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
             delete m;
         }
     }
-    menu->setStyleSheet(
-                         "QMenu {"
-                         "background-color:rgb(21,26,30);"
-                         "border: 1px solid #626c6e;"
-                         //"border-color:rgba(255,255,255,30);"    //边框颜色
-                         "font:SimSun 14px;"                       //字体，字体大小
-                         "color:rgba(255,255,255,100);"                //字体颜色
-                        "padding: 4px 2px 4px 2px;"
-                        " }"
-                        "QMenu::item {"
-                        "width: 244px;"
-                        "height: 90px;"
-                        "}"
-                        //鼠标悬停样式
-                        "QMenu:hover{"
-                        "background-color:rgba(190,216,239,30%);"
-                        "}"
-                        //鼠标按下样式
-                        "QMenu:selected{"
-                        "background-color:rgba(190,216,239,30%);"
-                        "}"
-
-                        );
 
 
     // Panel menu ...............................
@@ -1188,14 +1192,15 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
                    this, SLOT(showAddPluginDialog())
                   )->setDisabled(mLockPanel);
 */
+    /*
     menu->setWindowOpacity(0.9);
-    menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
+    menu->addAction(QIcon("/usr/share/ukui-panel/panel/img/setting.svg"),
                    tr("Set up Panel"),
                    this, SLOT(panelBackgroundChange())
                   )->setDisabled(mLockPanel);
 
     menu->addSeparator();
-
+*/
     menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
                    tr("Show Taskview"),
                    this, SLOT(showTaskView())
@@ -1220,45 +1225,24 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
     QAction *pmenuaction_l;
 
     pmenuaction_s=new QAction(this);
-    pmenuaction_s->setText("小尺寸");
+    pmenuaction_s->setText(tr("Small"));
     pmenuaction_m=new QAction(this);
-    pmenuaction_m->setText("中尺寸");
+    pmenuaction_m->setText(tr("Media"));
     pmenuaction_l=new QAction(this);
-    pmenuaction_l->setText("大尺寸");
+    pmenuaction_l->setText(tr("Large"));
 
 
     QMenu *pmenu_panelsize;
     pmenu_panelsize=new QMenu(this);
-    pmenu_panelsize->setTitle("调整大小");
+    pmenu_panelsize->setTitle(tr("Adjustment Size"));
     pmenu_panelsize->addAction(pmenuaction_s);
     pmenu_panelsize->addAction(pmenuaction_m);
     pmenu_panelsize->addAction(pmenuaction_l);
     menu->addMenu(pmenu_panelsize);
 
-
-    pmenu_panelsize->setStyleSheet(
-                         "QMenu {"
-                         "background-color:rgba(21,26,30,90%);"
-                         "border-color:rgba(255,255,255,30);"    //边框颜色
-                         "font:SimSun 14px;"                       //字体，字体大小
-                         "color:rgba(255,255,255,100);"                //字体颜色
-                         "padding:2px 2px; "                     //设置菜单项文字上下和左右的内边距，效果就是菜单中的条目左右上下有了间隔
-                        " }"
-
-                        //鼠标悬停样式
-                        "QToolButton:hover{"
-                        "background-color:rgba(190,216,239,30%);"
-                        "}"
-                        //鼠标按下样式
-                        "QToolButton:pressed{"
-                        "background-color:rgba(0,0,0,12%);"
-                        "}"
-
-                        );
-
-    connect(pmenuaction_s,SIGNAL(triggered()),this,SLOT(panelsizechange_s()));
-    connect(pmenuaction_m,SIGNAL(triggered()),this,SLOT(panelsizechange_m()));
-    connect(pmenuaction_l,SIGNAL(triggered()),this,SLOT(panelsizechange_l()));
+    connect(pmenuaction_s,SIGNAL(triggered()),this,SLOT(changeSizeToSmall()));
+    connect(pmenuaction_m,SIGNAL(triggered()),this,SLOT(changeSizeToMedium()));
+    connect(pmenuaction_l,SIGNAL(triggered()),this,SLOT(changeSizeToLarge()));
     menu->addSeparator();
 
     QAction *pmenuaction_top;
@@ -1266,45 +1250,26 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
     QAction *pmenuaction_left;
     QAction *pmenuaction_right;
     pmenuaction_top=new QAction(this);
-    pmenuaction_top->setText("上");
+    pmenuaction_top->setText(tr("Up"));
     pmenuaction_bottom=new QAction(this);
-    pmenuaction_bottom->setText("下");
+    pmenuaction_bottom->setText(tr("Bottom"));
     pmenuaction_left=new QAction(this);
-    pmenuaction_left->setText("左");
+    pmenuaction_left->setText(tr("Left"));
     pmenuaction_right=new QAction(this);
-    pmenuaction_right->setText("右");
+    pmenuaction_right->setText(tr("Right"));
     QMenu *pmenu_positon;
     pmenu_positon=new QMenu(this);
-    pmenu_positon->setTitle("调整位置");
+    pmenu_positon->setTitle(tr("Adjustment Position"));
     pmenu_positon->addAction(pmenuaction_top);
     pmenu_positon->addAction(pmenuaction_bottom);
     pmenu_positon->addAction(pmenuaction_left);
     pmenu_positon->addAction(pmenuaction_right);
     menu->addMenu(pmenu_positon);
-    pmenu_positon->setStyleSheet(
-                         "QMenu {"
-                         "background-color:rgba(21,26,30,90%);"
-                         "border-color:rgba(255,255,255,30);"    //边框颜色
-                         "font:SimSun 14px;"                       //字体，字体大小
-                         "color:rgba(255,255,255,100);"                //字体颜色
-                         "padding:2px 2px; "                     //设置菜单项文字上下和左右的内边距，效果就是菜单中的条目左右上下有了间隔
-                        " }"
 
-                        //鼠标悬停样式
-                        "QToolButton:hover{"
-                        "background-color:rgba(190,216,239,30%);"
-                        "}"
-                        //鼠标按下样式
-                        "QToolButton:pressed{"
-                        "background-color:rgba(0,0,0,12%);"
-                        "}"
-
-                        );
-
-    connect(pmenuaction_top,SIGNAL(triggered()),this,SLOT(changePosition_top()));
-    connect(pmenuaction_bottom,SIGNAL(triggered()),this,SLOT(changePosition_bottom()));
-    connect(pmenuaction_left,SIGNAL(triggered()),this,SLOT(changePosition_left()));
-    connect(pmenuaction_right,SIGNAL(triggered()),this,SLOT(changePosition_right()));
+    connect(pmenuaction_top,SIGNAL(triggered()),this,SLOT(changePositionToTop()));
+    connect(pmenuaction_bottom,SIGNAL(triggered()),this,SLOT(changePositionToBottom()));
+    connect(pmenuaction_left,SIGNAL(triggered()),this,SLOT(changePositionToLeft()));
+    connect(pmenuaction_right,SIGNAL(triggered()),this,SLOT(changePositionToRight()));
     pmenu_positon->setDisabled(mLockPanel);
 
 /*
@@ -1327,6 +1292,8 @@ void UKUIPanel::showPopupMenu(Plugin *plugin)
     act_lock->setCheckable(true);
     act_lock->setChecked(mLockPanel);
     connect(act_lock, &QAction::triggered, [this] { mLockPanel = !mLockPanel; saveSettings(false); });
+
+    //Hidden features, lock the panel
 /*
     menu->addAction(XdgIcon::fromTheme(QLatin1String("configure")),
                    tr("Reset Panel"),
@@ -1617,74 +1584,57 @@ bool UKUIPanel::isPluginSingletonAndRunnig(QString const & pluginId) const
         return plugin->iPlugin()->flags().testFlag(IUKUIPanelPlugin::SingleInstance);
 }
 
-void UKUIPanel::changePosition_top()
+void UKUIPanel::setPanelPosition(Position position)
 {
-    //mConfigWidget->positionChanged();
-     //qDebug()<<"mPanelPage"<<mConfigDialog->mPanelPage;
-    //mConfigDialog->mPanelPage->positionChanged();
-    if(mConfigDialog.isNull())
-    {
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
-    }
-    mConfigDialog->configPosition_top();
+    setPosition(0,position,true);
 }
 
-//change panel position
-void UKUIPanel::changePosition_bottom()
+void UKUIPanel::changePositionToTop()
 {
-    if(mConfigDialog.isNull())
-    {
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
-    }
-    mConfigDialog->configPosition_bottom();
+    setPosition(0,PositionTop,true);
+    gsettings->set(PANEL_POSITION_KEY,1);
 }
 
-void UKUIPanel::changePosition_left()
+void UKUIPanel::changePositionToBottom()
 {
-    if(mConfigDialog.isNull())
-    {
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
-    }
-    mConfigDialog->configPosition_left();
+    setPosition(0,PositionBottom,true);
+    gsettings->set(PANEL_POSITION_KEY,0);
 }
 
-void UKUIPanel::changePosition_right()
+void UKUIPanel::changePositionToLeft()
 {
-    if(mConfigDialog.isNull())
-    {
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
-    }
-    mConfigDialog->configPosition_right();
+    setPosition(0,PositionLeft,true);
+    gsettings->set(PANEL_POSITION_KEY,2);
 }
 
-//change panel size
-void UKUIPanel::panelsizechange_s()
+void UKUIPanel::changePositionToRight()
 {
-    if(mConfigDialog.isNull())
-    {
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
-    }
-    mConfigDialog->configPanelSize_S();
-
+    this->setPosition(0,PositionRight,true);
+    gsettings->set(PANEL_POSITION_KEY,3);
 }
 
-void UKUIPanel::panelsizechange_m()
+void UKUIPanel::changeSizeToSmall()
 {
-    if(mConfigDialog.isNull())
-    {
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
-    }
-    mConfigDialog->configPanelSize_m();
-
+    setPanelSize(PANEL_SIZE_SMALL,true);
+    setIconSize(ICON_SIZE_SMALL,true);
+    gsettings->set(PANEL_SIZE_KEY,PANEL_SIZE_SMALL);
+    gsettings->set(ICON_SIZE_KEY,ICON_SIZE_SMALL);
 }
 
-void UKUIPanel::panelsizechange_l()
+void UKUIPanel::changeSizeToMedium()
 {
-    if(mConfigDialog.isNull())
-    {
-        mConfigDialog = new ConfigPanelDialog(this, nullptr);
-    }
-    mConfigDialog->configPanelSize_l();
+    setPanelSize(PANEL_SIZE_MEDIUM,true);
+    setIconSize(ICON_SIZE_MEDIUM,true);
+    gsettings->set(PANEL_SIZE_KEY,PANEL_SIZE_MEDIUM);
+    gsettings->set(ICON_SIZE_KEY,ICON_SIZE_MEDIUM);
+}
+
+void UKUIPanel::changeSizeToLarge()
+{
+    setPanelSize(PANEL_SIZE_LARGE,true);
+    setIconSize(ICON_SIZE_MEDIUM,true);
+    gsettings->set(PANEL_SIZE_KEY,PANEL_SIZE_LARGE);
+    gsettings->set(ICON_SIZE_KEY,ICON_SIZE_LARGE);
 }
 
 void UKUIPanel::panelReset()
