@@ -40,11 +40,21 @@
 #include <QDebug>
 #include <QApplication>
 #include <QtWebKit/qwebsettings.h>
+#include <QStyleOption>
 #include <glib.h>
 #include <gio/gio.h>
-
 #define CALENDAR_HEIGHT (40)
-#define CALENDAR_WIDTH (85)
+#define CALENDAR_WIDTH (104)
+
+#define WEBVIEW_WIDTH (454)
+#define WEBVIEW_MAX_HEIGHT (704)
+#define WEBVIEW_MIN_HEIGHT (600)
+#define HOUR_SYSTEM_CONTROL "org.ukui.control-center.panel.plugins"
+#define HOUR_SYSTEM_24_Horizontal "hh:mm ddd  yyyy/MM/dd"
+#define HOUR_SYSTEM_24_Vertical "hh:mm ddd  MM/dd"
+#define HOUR_SYSTEM_12_Horizontal   "Ahh:mm ddd  yyyy/MM/dd"
+#define HOUR_SYSTEM_12_Vertical   "Ahh:mm ddd  MM/dd"
+#define HOUR_SYSTEM_KEY "hoursystem"
 
 IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupInfo):
     QWidget(),
@@ -55,12 +65,14 @@ IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupI
     mbActived(false),
     mbIsNeedUpdate(false),
     mbHasCreatedWebView(false),
+    mViewWidht(WEBVIEW_WIDTH),
+    mViewHeight(0),
     mPopupContent(NULL),
     mWebViewDiag(NULL)
 {
 
     mMainWidget = new QWidget();
-    mContent = new CalendarActiveLabel;
+    mContent = new CalendarActiveLabel(this);
     mWebViewDiag = new UkuiWebviewDialog;
 
     mRotatedWidget = new UKUi::RotatedWidget(*mContent, mMainWidget);
@@ -82,6 +94,35 @@ IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupI
     connect(mTimer, SIGNAL(timeout()), SLOT(timeout()));
     connect(mContent, SIGNAL(wheelScrolled(int)), SLOT(wheelScrolled(int)));
     connect(mWebViewDiag, SIGNAL(deactivated()), SLOT(hidewebview()));
+    const QByteArray id(HOUR_SYSTEM_CONTROL);
+    if(QGSettings::isSchemaInstalled(id)) {
+    gsettings = new QGSettings(id);
+
+    connect(gsettings, &QGSettings::changed, this, [=] (const QString &key)
+    {
+        if (key == HOUR_SYSTEM_KEY)
+        {
+            if(gsettings->keys().contains("hoursystem"))
+            {
+            hourSystemMode=gsettings->get("hoursystem").toString();
+            }
+            else
+                hourSystemMode=24;
+        }
+        else if(key == "calendar")
+        {
+
+            mbHasCreatedWebView = false;
+            initializeCalendar();
+        }
+        else if(key == "firstday")
+        {
+            qDebug()<<"key == firstday";
+            mbHasCreatedWebView = false;
+            initializeCalendar();
+        }
+    });
+    }
 
     setTimeShowStyle();
     mContent->setStyleSheet(
@@ -89,8 +130,7 @@ IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupI
                 "QLabel{"
                 /*"background-color:rgba(100,225,100,80%);"//背景色（也可以设置图片）*/
                 "border-width:0px;"                     //边框宽度像素
-                "border-radius:0px;"                   //边框圆角半径像素
-                "font:SimSun 14px;"                       //字体，字体大小
+                "border-radius:6px;"                   //边框圆角半径像素
                 "color:rgba(255,255,255,100%);"                //字体颜色
                 "padding:0px;"                          //填衬
                 "textalignment:aligncenter"               //文本居中
@@ -110,10 +150,9 @@ IndicatorCalendar::IndicatorCalendar(const IUKUIPanelPluginStartupInfo &startupI
 
 IndicatorCalendar::~IndicatorCalendar()
 {
-     qDebug()<<"calend exit start";
     if(mMainWidget != NULL)
     {
-     mMainWidget->deleteLater();
+        mMainWidget->deleteLater();
     }
     if(mWebViewDiag != NULL)
     {
@@ -121,15 +160,15 @@ IndicatorCalendar::~IndicatorCalendar()
     }
     if(mRotatedWidget != NULL)
     {
-     mRotatedWidget->deleteLater();
+        mRotatedWidget->deleteLater();
     }
     if(mContent != NULL)
     {
-     mContent->deleteLater();
+        mContent->deleteLater();
     }
     if(mPopupContent != NULL)
     {
-     mPopupContent->deleteLater();
+        mPopupContent->deleteLater();
     }
 }
 
@@ -149,6 +188,7 @@ void IndicatorCalendar::updateTimeText()
     QTimeZone timeZone(timeZoneName.toLatin1());
     QDateTime tzNow = now.toTimeZone(timeZone);
 
+
     bool isUpToDate(true);
     if (!mShownTime.isValid()) // first time or forced update
     {
@@ -186,20 +226,61 @@ void IndicatorCalendar::updateTimeText()
         }
     }
 
-    if (!isUpToDate || mbIsNeedUpdate)
-    {
+//    if (!isUpToDate || mbIsNeedUpdate)
+//    {
         const QSize old_size = mContent->sizeHint();
         QString str;
-        if(panel()->isHorizontal())
+        const QByteArray id(HOUR_SYSTEM_CONTROL);
+        if(QGSettings::isSchemaInstalled(id))
         {
-            str=tzNow.toString("hh:mm dddd  yyyy-MM-dd");
+        gsettings = new QGSettings(id);
+        QStringList keys = gsettings->keys();
+        if(keys.contains("hoursystem")){
+            hourSystemMode=gsettings->get("hoursystem").toString();
+        }
+        if(!gsettings)
+        {
+            qDebug()<<"gsettings  get error    :";
+            return;
+        }
+        if(!QString::compare("24",hourSystemMode))
+        {
+            if(panel()->isHorizontal())
+            {
+                str=tzNow.toString(HOUR_SYSTEM_24_Horizontal);
+//                str=tzNow.toString(HOUR_SYSTEM_24_Horizontal);
+            }
+            else
+            {
+                str=tzNow.toString(HOUR_SYSTEM_24_Vertical);
+            }
+
         }
         else
         {
-            str=tzNow.toString("hh:mm dddd  MM-dd");
+            if(panel()->isHorizontal())
+            {
+                str=tzNow.toString(HOUR_SYSTEM_12_Horizontal);
+            }
+            else
+            {
+                str = tzNow.toString(HOUR_SYSTEM_12_Vertical);
+                str.replace("AM","AM ");
+                str.replace("PM","PM ");
+            }
         }
-        str.replace("-","/");
-        str.replace("星期","周");
+//        if(QLocale::system().name() == "zh_CN")
+//        {
+//            str.replace("-","/");
+//            str.replace("星期","周");
+//            str.remove("/上午");
+//            str.remove("/下午");
+//            mContent->setText(str);
+//        }
+//        else
+//        {
+//            mContent->setText(tzNow.toString("Ahh:mm ddd  yyyy/MM/dd"));
+//        }
         mContent->setText(str);
         if (old_size != mContent->sizeHint())
         {
@@ -208,7 +289,8 @@ void IndicatorCalendar::updateTimeText()
         mRotatedWidget->update();
         updatePopupContent();
         mbIsNeedUpdate = false;
-    }
+        }
+
 }
 
 void IndicatorCalendar::setTimeText()
@@ -423,11 +505,79 @@ void IndicatorCalendar::wheelScrolled(int delta)
 /*when widget is loading need initialize here*/
 void IndicatorCalendar::initializeCalendar()
 {
+    QByteArray id(HOUR_SYSTEM_CONTROL);
+    CalendarShowMode showCalendar = defaultMode;
+    QString lunarOrsolar;
+    QString firstDay;
+    if(QGSettings::isSchemaInstalled(id))
+    {
+//        if(gsettings)
+//        {
+//            gsettings->deleteLater();
+//        }
+//        gsettings = new QGSettings(id);
+        if(!gsettings)
+        {
+            qDebug()<<"get gsetting error!!!";
+            return;
+        }
+        if(gsettings->keys().contains("calendar"))
+        {
+            lunarOrsolar= gsettings->get("calendar").toString();
+        }
+        if(gsettings->keys().contains("firstday"))
+        {
+            firstDay= gsettings->get("firstday").toString();
+        }
+        qDebug()<<"QLocale::system().name():"<<QLocale::system().name();
+        if (QLocale::system().name() == "zh_CN")
+        {
+
+            if(lunarOrsolar == "lunar")
+            {
+                if(firstDay == "sunday")
+                {
+                    showCalendar = lunarSunday;
+                }
+                else if(firstDay == "monday")
+                {
+                    showCalendar = lunarMonday;
+                }
+                mViewHeight = WEBVIEW_MAX_HEIGHT;
+            }
+            else if(lunarOrsolar == "solarlunar")
+            {
+                if(firstDay == "sunday")
+                {
+                    showCalendar = solarSunday;
+                }
+                else if(firstDay == "monday")
+                {
+                    showCalendar = solarMonday;
+                }
+                mViewHeight = WEBVIEW_MIN_HEIGHT;
+            }
+        }
+        else// for internaitional
+        {
+            if(firstDay == "sunday")
+            {
+                showCalendar = solarSunday;
+            }
+            else if(firstDay == "monday")
+            {
+                showCalendar = solarMonday;
+            }
+            mViewHeight = WEBVIEW_MIN_HEIGHT;
+        }
+    }
+
     if(mWebViewDiag != NULL )
     {
         if(!mbHasCreatedWebView)
         {
-            mWebViewDiag->creatwebview();
+            qDebug()<<"showCalendar:"<<showCalendar;
+            mWebViewDiag->creatwebview(showCalendar);
             mbHasCreatedWebView = true;
         }
     }
@@ -440,7 +590,7 @@ void IndicatorCalendar::activated(ActivationReason reason)
 //        QString  htmlFilePath = QLatin1String(PACKAGE_DATA_DIR);
 //        htmlFilePath = QLatin1String("file://") + htmlFilePath + QLatin1String("/plugin-calendar/html/ukui.html");
 
-        mWebViewDiag->setGeometry(calculatePopupWindowPos(QSize(480,400)));
+        mWebViewDiag->setGeometry(calculatePopupWindowPos(QSize(mViewWidht,mViewHeight)));
         mWebViewDiag->show();
         setbackground();
         if(!mbActived)
@@ -653,13 +803,6 @@ void IndicatorCalendar::setbackground()
     }
     if (!strcmp (color_hex, "#000000")){
         str=QString::asprintf("\
-                      var zodiac_icon = document.getElementById('zodiac_icon');\
-                      zodiac_icon.setAttribute('src', '/usr/share/ukui-panel/plugin-calendar/html/images/zodiac/black/mouse-black.png');\
-                      zodiac_icon.setAttribute('style', 'padding-top: 33px');\
-                      var checkbox = document.getElementById('checkbox');\
-                      if (checkbox.checked){\
-                          zodiac_icon.setAttribute('style', 'display:none');\
-                      }\
                       document.getElementById('container').style.background='%s';\
                       document.getElementById('header').style.background='%s';\
                       document.getElementById('day').style.color='%s';\
@@ -731,13 +874,6 @@ void IndicatorCalendar::setbackground()
     }
     else{
         str=QString::asprintf("\
-                      var zodiac_icon = document.getElementById('zodiac_icon');\
-                      zodiac_icon.setAttribute('src', '/usr/share/ukui-panel/plugin-calendar/html/images/zodiac/blue/mouse-white.png');\
-                      zodiac_icon.setAttribute('style', 'padding-top: 33px');\
-                      var checkbox = document.getElementById('checkbox');\
-                      if (checkbox.checked){\
-                          zodiac_icon.setAttribute('style', 'display:none');\
-                      }\
                                       document.getElementById('container').style.background='%s';\
                                       document.getElementById('header').style.background='%s';\
                                       document.getElementById('day').style.color='%s';\
@@ -775,8 +911,9 @@ void IndicatorCalendar::setbackground()
 }
 
 
-CalendarActiveLabel::CalendarActiveLabel(QWidget *parent) :
-    QLabel(parent)
+CalendarActiveLabel::CalendarActiveLabel(IUKUIPanelPlugin *plugin, QWidget *parent) :
+    QLabel(parent),
+    mPlugin(plugin)
 {
 }
 
@@ -804,3 +941,33 @@ void CalendarActiveLabel::mouseReleaseEvent(QMouseEvent* event)
 
     QLabel::mouseReleaseEvent(event);
 }
+
+void CalendarActiveLabel::contextMenuEvent(QContextMenuEvent *event)
+{
+    PopupMenu *menuCalender=new PopupMenu(this);
+    menuCalender->setAttribute(Qt::WA_DeleteOnClose);
+
+    menuCalender->addAction(QIcon::fromTheme("document-page-setup"),
+                   tr("Time and Date Setting"),
+                   this, SLOT(setControlTime())
+                  );
+    /*
+    menuCalender->addAction(QIcon::fromTheme("document-page-setup"),
+                   tr("Config panel"),
+                   this, SLOT(setUpPanel())
+                  );
+    */
+    menuCalender->setGeometry(mPlugin->panel()->calculatePopupWindowPos(mapToGlobal(event->pos()), menuCalender->sizeHint()));
+    menuCalender->show();
+}
+
+void CalendarActiveLabel::setControlTime()
+{
+    system("ukui-control-center");
+}
+/*
+void CalendarActiveLabel::setUpPanel()
+{
+    system("ukui-control-center -d");
+}
+*/
