@@ -2,8 +2,8 @@
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
+ * it under the terms of the GNU General Public as published by
+ * the Free Software Foundation; either version 2.1, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -28,6 +28,15 @@ namespace Ui {
 class UkuiWebviewDialog;
 }
 
+enum CalendarShowMode
+{
+    lunarSunday        = 0,//show lunar and first day a week is sunday
+    lunarMonday        = 1,//show lunar and first day a week is monday
+    solarSunday        = 2,//show solar and first day a week is sunday
+    solarMonday        = 3,//show solar and first day a week is monday
+    Unknown            = 0xff
+};
+
 class UkuiWebviewDialog : public QDialog
 {
     Q_OBJECT
@@ -35,7 +44,7 @@ class UkuiWebviewDialog : public QDialog
 public:
     explicit UkuiWebviewDialog(QWidget *parent = nullptr);
     ~UkuiWebviewDialog();
-    void creatwebview();
+    void creatwebview(int _mode);
     void showinfo(QString string);
     QWebView *webview(){return mWebView;}
 Q_SIGNALS:
