@@ -2,6 +2,7 @@
  * (c)LGPL2+
  *
  * Copyright: 2011 Razor team
+ *            2014 LXQt team
  * Authors:
  *   Alexander Sokoloff <sokoloff.a@gmail.com>
  *   Maciej Płaza <plaza.maciej@gmail.com>
@@ -70,6 +71,10 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
     mPlaceHolder(new QWidget(this)),
     mStyle(new LeftAlignedTextStyle())
 {
+    taskstatus=NORMAL;
+    setAttribute(Qt::WA_TranslucentBackground);//设置窗口背景透明
+    setWindowFlags(Qt::FramelessWindowHint);   //设置无边框窗口
+
     setStyle(mStyle);
     mLayout = new UKUi::GridLayout(this);
     setLayout(mLayout);
@@ -302,6 +307,7 @@ void UKUITaskBar::addWindow(WId window)
             buttonMove(qobject_cast<UKUITaskGroup *>(sender()), qobject_cast<UKUITaskGroup *>(dragSource), pos);
         });
 
+        group->setFixedSize(panel()->panelSize(),panel()->panelSize());
         mLayout->addWidget(group);
         group->setToolButtonsStyle(mButtonStyle);
     }
@@ -438,7 +444,7 @@ void UKUITaskBar::setButtonStyle(Qt::ToolButtonStyle buttonStyle)
 
 void UKUITaskBar::setShowGroupOnHover(bool bFlag)
 {
-
+    mShowGroupOnHover = bFlag;
 }
 
 /************************************************
@@ -512,11 +518,13 @@ void UKUITaskBar::realign()
     refreshButtonRotation();
 
     IUKUIPanel *panel = mPlugin->panel();
-    QSize maxSize = QSize(50, mButtonHeight);
+    //set taskbar width by panel
+    QSize maxSize = QSize(100, mButtonHeight);
     QSize minSize = QSize(0, 0);
+    int iconsize = panel->iconSize();
+    int panelsize = panel->panelSize();
 
     bool rotated = false;
-
     if (panel->isHorizontal())
     {
         mLayout->setRowCount(panel->lineCount());
@@ -550,6 +558,13 @@ void UKUITaskBar::realign()
         }
     }
 
+    for(auto it= mKnownWindows.begin(); it != mKnownWindows.end();it++)
+    {
+        UKUITaskGroup *group = it.value();
+        group->setFixedSize(panelsize, panelsize);
+        group->setIconSize(QSize(iconsize,iconsize));
+        group->updateIcon();
+    }
     mLayout->setCellMinimumSize(minSize);
     mLayout->setCellMaximumSize(maxSize);
     mLayout->setDirection(rotated ? UKUi::GridLayout::TopToBottom : UKUi::GridLayout::LeftToRight);
@@ -565,6 +580,7 @@ void UKUITaskBar::realign()
  ************************************************/
 void UKUITaskBar::wheelEvent(QWheelEvent* event)
 {
+#if 0
     if (!mCycleOnWheelScroll)
         return QFrame::wheelEvent(event);
 
@@ -602,7 +618,7 @@ void UKUITaskBar::wheelEvent(QWheelEvent* event)
     UKUITaskButton *button = NULL;
 
     // switching between groups from temporary list in modulo addressing
-    while (!button)
+    while (!button)conSize()
     {
         button = group->getNextPrevChildButton(delta == 1, !(list.count() - 1));
         if (button)
@@ -611,6 +627,7 @@ void UKUITaskBar::wheelEvent(QWheelEvent* event)
         group = list.at(idx);
     }
     QFrame::wheelEvent(event);
+#endif
 }
 
 /************************************************
@@ -698,3 +715,47 @@ void UKUITaskBar::activateTask(int pos)
         }
     }
 }
+
+void UKUITaskBar::enterEvent(QEvent *)
+{
+    taskstatus=HOVER;
+    update();
+}
+
+void UKUITaskBar::leaveEvent(QEvent *)
+{
+    taskstatus=NORMAL;
+    update();
+}
+
+void UKUITaskBar::paintEvent(QPaintEvent *)
+{
+        QStyleOption opt;
+        opt.initFrom(this);
+        QPainter p(this);
+
+        switch(taskstatus)
+          {
+          case NORMAL:
+              {
+//                  p.setBrush(QBrush(QColor(0xFF,0xFF,0xFF,0x19)));
+                  p.setPen(Qt::NoPen);
+                  break;
+              }
+          case HOVER:
+              {
+//                  p.setBrush(QBrush(QColor(0xFF,0xFF,0xFF,0x19)));
+                  p.setPen(Qt::NoPen);
+                  break;
+              }
+          case PRESS:
+              {
+//                  p.setBrush(QBrush(QColor(0x13,0x14,0x14,0xb2)));
+                  p.setPen(Qt::NoPen);
+                  break;
+              }
+          }
+        p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
+        p.drawRoundedRect(opt.rect,6,6);
+        style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
+}
