@@ -2,6 +2,7 @@
  * (c)LGPL2+
  *
  * Copyright: 2011 Razor team
+ *            2014 LXQt team
  * Authors:
  *   Alexander Sokoloff <sokoloff.a@gmail.com>
  *   Kuzma Shapran <kuzma.shapran@gmail.com>
@@ -84,6 +85,7 @@ UKUITaskButton::UKUITaskButton(const WId window, UKUITaskBar * taskbar, QWidget
     mDNDTimer(new QTimer(this))
 {
     Q_ASSERT(taskbar);
+    taskbuttonstatus=NORMAL;
 
     setCheckable(true);
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
@@ -107,28 +109,25 @@ UKUITaskButton::UKUITaskButton(const WId window, UKUITaskBar * taskbar, QWidget
                 "border-width:2px;"                     //边框宽度像素
                 "}"
                 );
-    mParentTaskBar->setStyleSheet(
+    this->setStyleSheet(
                 //正常状态样式
                 "QToolButton{"
-                "background-color:rgba(190,216,239,5%);"
+                "background-color:rgba(190,216,239,8%);"
                                 "border-style:outset;"                  //边框样式（inset/outset）
+                                "border-color:rgba(190,216,239,0%);"    //边框颜色
                                 "qproperty-iconSize: 28px 28px;"
-                                "border-width:2px;"                     //边框宽度像素
-                                "border-radius:2px;"                   //边框圆角半径像素
-                                "font:bold 14px;"                       //字体，字体大小
-                                "color:rgba(0,0,0,100);"                //字体颜色
+                                "border-width:4px;"                     //边框宽度像素
+                                "border-radius:6px;"                   //边框圆角半径像素
                                 "padding:0px;"
                 "}"
                 //鼠标悬停样式
                 "QToolButton:hover{"
-                "background-color:rgba(190,216,239,20%);"
+                "background-color:rgba(190,216,239,12%);"
                 "}"
                 //鼠标按下样式
                 "QToolButton:pressed{"
-                "background-color:rgba(190,216,239,12%);"
+                "background-color:rgba(190,216,239,6%);"
                 "}"
-
-
                 );
 }
 
@@ -163,6 +162,8 @@ void UKUITaskButton::updateIcon()
     if (ico.isNull())
     {
         ico = KWindowSystem::icon(mWindow);
+//        ico = XdgIcon::fromTheme(QString::fromUtf8(KWindowInfo{mWindow, 0, NET::WM2WindowClass}.windowClassClass()).toLower());
+
     }
     setIcon(ico.isNull() ? XdgIcon::defaultApplicationIcon() : ico);
 }
@@ -256,13 +257,15 @@ void UKUITaskButton::mousePressEvent(QMouseEvent* event)
  ************************************************/
 void UKUITaskButton::mouseReleaseEvent(QMouseEvent* event)
 {
-    if (event->button() == Qt::LeftButton)
-    {
-        if (isChecked())
-            minimizeApplication();
-        else
-            raiseApplication();
-    }
+//    if (event->button() == Qt::LeftButton)
+//    {
+//        if (isChecked())
+//            minimizeApplication();
+//        else
+//        {
+//            raiseApplication();
+//        }
+//    }
     QToolButton::mouseReleaseEvent(event);
 
 }
@@ -752,50 +755,62 @@ void UKUITaskButton::setAutoRotation(bool value, IUKUIPanel::Position position)
         setOrigin(Qt::TopLeftCorner);
 }
 
+void UKUITaskButton::enterEvent(QEvent *)
+{
+    taskbuttonstatus=HOVER;
+    update();
+}
+
+void UKUITaskButton::leaveEvent(QEvent *)
+{
+    taskbuttonstatus=NORMAL;
+    update();
+}
+
 void UKUITaskButton::paintEvent(QPaintEvent *event)
 {
-    if (mOrigin == Qt::TopLeftCorner)
-    {
-        QToolButton::paintEvent(event);
-        return;
-    }
+//    if (mOrigin == Qt::TopLeftCorner)
+//    {
+//        QToolButton::paintEvent(event);
+//        return;
+//    }
 
     QSize sz = size();
-    QSize adjSz = sz;
+    QSize adjSz (mPlugin->panel()->panelSize(),mPlugin->panel()->panelSize());
     QTransform transform;
     QPoint originPoint;
 
-    switch (mOrigin)
-    {
-    case Qt::TopLeftCorner:
-        transform.rotate(0.0);
-        originPoint = QPoint(0.0, 0.0);
-        break;
+//    switch (mOrigin)
+//    {
+//    case Qt::TopLeftCorner:
+//        transform.rotate(0.0);
+//        originPoint = QPoint(0.0, 0.0);
+//        break;
 
-    case Qt::TopRightCorner:
-        transform.rotate(90.0);
-        originPoint = QPoint(0.0, -sz.width());
-        adjSz.transpose();
-        break;
+//    case Qt::TopRightCorner:
+//        transform.rotate(90.0);
+//        originPoint = QPoint(0.0, -sz.width());
+//        adjSz.transpose();
+//        break;
 
-    case Qt::BottomRightCorner:
-        transform.rotate(180.0);
-        originPoint = QPoint(-sz.width(), -sz.height());
-        break;
+//    case Qt::BottomRightCorner:
+//        transform.rotate(180.0);
+//        originPoint = QPoint(-sz.width(), -sz.height());
+//        break;
 
-    case Qt::BottomLeftCorner:
-        transform.rotate(270.0);
-        originPoint = QPoint(-sz.height(), 0.0);
-        adjSz.transpose();
-        break;
-    }
+//    case Qt::BottomLeftCorner:
+//        transform.rotate(270.0);
+//        originPoint = QPoint(-sz.height(), 0.0);
+//        adjSz.transpose();
+//        break;
+//    }
 
     bool drawPixmapNextTime = false;
 
     if (!mDrawPixmap)
     {
         mPixmap = QPixmap(adjSz);
-        mPixmap.fill(QColor(0, 0, 0, 0));
+        mPixmap.fill(QColor(255, 0, 0, 0));
 
         if (adjSz != sz)
             resize(adjSz); // this causes paint event to be repeated - next time we'll paint the pixmap to the widget surface.
@@ -804,6 +819,7 @@ void UKUITaskButton::paintEvent(QPaintEvent *event)
         QStylePainter painter(&mPixmap, this);
         QStyleOptionToolButton opt;
         initStyleOption(&opt);
+        painter.setBrush(QBrush(QColor(0xFF,0xFF,0xFF,0x19)));
         painter.drawComplexControl(QStyle::CC_ToolButton, opt);
         // }
 
