@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * Copyright: 2011 Razor team
- *            2014 UKUi team
+ *            2014 LXQt team
  * Authors:
  *   Alexander Sokoloff <sokoloff.a@gmail.com>
  *   Maciej Płaza <plaza.maciej@gmail.com>
@@ -52,8 +52,9 @@
 #include <QApplication>
 #include "../panel/iukuipanelplugin.h"
 #include <QSize>
-#define PREVIEW_WIDTH		168
-#define PREVIEW_HEIGHT		128
+#include <QScreen>
+#define PREVIEW_WIDTH		468
+#define PREVIEW_HEIGHT		428
 #define SPACE_WIDTH			8
 #define SPACE_HEIGHT		8
 #define THUMBNAIL_WIDTH		(PREVIEW_WIDTH - SPACE_WIDTH)
@@ -61,6 +62,20 @@
 #define ICON_WIDTH			48
 #define ICON_HEIGHT			48
 
+#define SCREEN_MAX_WIDTH_SIZE     1400
+#define SCREEN_MAX_HEIGHT_SIZE    1050
+
+#define SCREEN_MIN_WIDTH_SIZE    800
+#define SCREEN_MIN_HEIGHT_SIZE   600
+
+#define SCREEN_MID_WIDTH_SIZE    1600
+
+#define PREVIEW_WIDGET_MAX_WIDTH            352
+#define PREVIEW_WIDGET_MAX_HEIGHT           264
+
+#define PREVIEW_WIDGET_MIN_WIDTH            276
+#define PREVIEW_WIDGET_MIN_HEIGHT           200
+
 QPixmap qimageFromXImage(XImage* ximage)
 {
     QImage::Format format = QImage::Format_ARGB32_Premultiplied;
@@ -121,9 +136,12 @@ UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *
     mGroupName(groupName),
     mPopup(new UKUIGroupPopup(this)),
     mPreventPopup(false),
-    mSingleButton(true)
+    mSingleButton(true),
+    mTimer(new QTimer(this)),
+    mpWidget(NULL)
 {
     Q_ASSERT(parent);
+    taskgroupStatus = NORMAL;
 
     setObjectName(groupName);
     setText(groupName);
@@ -136,6 +154,27 @@ UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *
     connect(parent, &UKUITaskBar::buttonStyleRefreshed, this, &UKUITaskGroup::setToolButtonsStyle);
     connect(parent, &UKUITaskBar::showOnlySettingChanged, this, &UKUITaskGroup::refreshVisibility);
     connect(parent, &UKUITaskBar::popupShown, this, &UKUITaskGroup::groupPopupShown);
+    mTimer->setTimerType(Qt::PreciseTimer);
+    connect(mTimer, SIGNAL(timeout()), SLOT(timeout()));
+}
+
+UKUITaskGroup::~UKUITaskGroup()
+{
+//    if(mPopup)
+//    {
+//        mPopup->deleteLater();
+//        mPopup = NULL;
+//    }
+//    if(mpWidget)
+//    {
+//        mpWidget->deleteLater();
+//        mpWidget = NULL;
+//    }
+//    if(VLayout)
+//    {
+//        VLayout->deleteLater();
+//        VLayout = NULL;
+//    }
 }
 
 /************************************************
@@ -153,7 +192,7 @@ void UKUITaskGroup::contextMenuEvent(QContextMenuEvent *event)
 
     QMenu * menu = new QMenu(tr("Group"));
     menu->setAttribute(Qt::WA_DeleteOnClose);
-    QAction *a = menu->addAction(XdgIcon::fromTheme("process-stop"), tr("关闭"));
+    QAction *a = menu->addAction(XdgIcon::fromTheme("process-stop"), tr("close"));
     connect(a, SIGNAL(triggered()), this, SLOT(closeGroup()));
     connect(menu, &QMenu::aboutToHide, [this] {
         mPreventPopup = false;
@@ -168,7 +207,8 @@ void UKUITaskGroup::contextMenuEvent(QContextMenuEvent *event)
  ************************************************/
 void UKUITaskGroup::closeGroup()
 {
-    for (UKUITaskButton *button : qAsConst(mButtonHash) )
+    //To Do
+    for (UKUITaskWidget *button : qAsConst(mButtonHash) )
         if (button->isOnDesktop(KWindowSystem::currentDesktop()))
             button->closeApplication();
 }
@@ -176,41 +216,16 @@ void UKUITaskGroup::closeGroup()
 /************************************************
 
  ************************************************/
-UKUITaskButton * UKUITaskGroup::addWindow(WId id)
+QWidget * UKUITaskGroup::addWindow(WId id)
 {
+
     if (mButtonHash.contains(id))
         return mButtonHash.value(id);
-
-    UKUITaskButton *btn = new UKUITaskButton(id, parentTaskBar(), mPopup);
-    btn->setToolButtonStyle(popupButtonStyle());
-
-    btn->setStyleSheet(
-                //正常状态样式
-                "QToolButton{"
-                "background-color:rgba(190,216,239,5%);"//背景色（也可以设置图片）
-                "qproperty-iconSize:24px 24px;"
-                "border-style:outset;"                  //边框样式（inset/outset）
-                "border-width:0px;"                     //边框宽度像素
-                "border-radius:0px;"                   //边框圆角半径像素
-                "border-color:rgba(255,255,255,30);"    //边框颜色
-                "font:bold 14px;"                       //字体，字体大小
-                "color:rgba(255,255,255,100%);"                //字体颜色
-                "padding:0px;"                          //填衬
-                "spacing:0px;"
-                "border-bottom-style:solid"
-                "}"
-                );
-
-    if (btn->isApplicationActive())
-    {
-        btn->setChecked(true);
-        setChecked(true);
-    }
-
+    UKUITaskWidget *btn = new UKUITaskWidget(id, parentTaskBar(), mPopup);
     mButtonHash.insert(id, btn);
-    //mPopup->addButton(btn);
 
     connect(btn, SIGNAL(clicked()), this, SLOT(onChildButtonClicked()));
+    connect(btn, SIGNAL(windowMaximize()), this, SLOT(onChildButtonClicked()));
     refreshVisibility();
 
     return btn;
@@ -219,11 +234,11 @@ UKUITaskButton * UKUITaskGroup::addWindow(WId id)
 /************************************************
 
  ************************************************/
-UKUITaskButton * UKUITaskGroup::checkedButton() const
+QWidget * UKUITaskGroup::checkedButton() const
 {
-    for (UKUITaskButton* button : qAsConst(mButtonHash))
-        if (button->isChecked())
-            return button;
+//    for (QWidget* button : qAsConst(mButtonHash))
+//        if (button->isChecked())
+//            return button;
 
     return NULL;
 }
@@ -231,9 +246,10 @@ UKUITaskButton * UKUITaskGroup::checkedButton() const
 /************************************************
 
  ************************************************/
-UKUITaskButton * UKUITaskGroup::getNextPrevChildButton(bool next, bool circular)
+QWidget * UKUITaskGroup::getNextPrevChildButton(bool next, bool circular)
 {
-    UKUITaskButton *button = checkedButton();
+#if 0
+    QWidget *button = checkedButton();
     int idx = mPopup->indexOf(button);
     int inc = next ? 1 : -1;
     idx += inc;
@@ -271,7 +287,8 @@ UKUITaskButton * UKUITaskGroup::getNextPrevChildButton(bool next, bool circular)
             return button;
     }
 
-    return NULL;
+#endif
+     return NULL;
 }
 
 /************************************************
@@ -279,16 +296,16 @@ UKUITaskButton * UKUITaskGroup::getNextPrevChildButton(bool next, bool circular)
  ************************************************/
 void UKUITaskGroup::onActiveWindowChanged(WId window)
 {
-    UKUITaskButton *button = mButtonHash.value(window, nullptr);
-    for (UKUITaskButton *btn : qAsConst(mButtonHash))
-        btn->setChecked(false);
+    UKUITaskWidget *button = mButtonHash.value(window, nullptr);
+//    for (QWidget *btn : qAsConst(mButtonHash))
+//        btn->setChecked(false);
 
-    if (button)
-    {
-        button->setChecked(true);
-        if (button->hasUrgencyHint())
-            button->setUrgencyHint(false);
-    }
+//    if (button)
+//    {
+//        button->setChecked(true);
+//        if (button->hasUrgencyHint())
+//            button->setUrgencyHint(false);
+//    }
     setChecked(nullptr != button);
 }
 
@@ -307,13 +324,23 @@ void UKUITaskGroup::onWindowRemoved(WId window)
 {
     if (mButtonHash.contains(window))
     {
-        UKUITaskButton *button = mButtonHash.value(window);
+        UKUITaskWidget *button = mButtonHash.value(window);
         mButtonHash.remove(window);
         mPopup->removeWidget(button);
         button->deleteLater();
 
         if (mButtonHash.count())
-            regroup();
+        {
+            if(mPopup->isVisible())
+            {
+                mPopup->hide();
+                showPreview();
+            }
+            else
+            {
+                regroup();
+            }
+        }
         else
         {
             if (isVisible())
@@ -331,6 +358,10 @@ void UKUITaskGroup::onWindowRemoved(WId window)
 void UKUITaskGroup::onChildButtonClicked()
 {
     setPopupVisible(false, true);
+    parentTaskBar()->setShowGroupOnHover(true);
+    //QToolButton::leaveEvent(event);
+    taskgroupStatus = NORMAL;
+    update();
 }
 
 /************************************************
@@ -351,11 +382,11 @@ void UKUITaskGroup::setToolButtonsStyle(Qt::ToolButtonStyle style)
 {
     setToolButtonStyle(style);
 
-    const Qt::ToolButtonStyle styleInPopup = popupButtonStyle();
-    for (auto & button : mButtonHash)
-    {
-        button->setToolButtonStyle(styleInPopup);
-    }
+//    const Qt::ToolButtonStyle styleInPopup = popupButtonStyle();
+//    for (auto & button : mButtonHash)
+//    {
+//        button->setToolButtonStyle(styleInPopup);
+//    }
 }
 
 /************************************************
@@ -372,7 +403,7 @@ int UKUITaskGroup::buttonsCount() const
 int UKUITaskGroup::visibleButtonsCount() const
 {
     int i = 0;
-    for (UKUITaskButton *btn : qAsConst(mButtonHash))
+    for (UKUITaskWidget *btn : qAsConst(mButtonHash))
         if (btn->isVisibleTo(mPopup))
             i++;
     return i;
@@ -392,13 +423,36 @@ void UKUITaskGroup::draggingTimerTimeout()
  ************************************************/
 void UKUITaskGroup::onClicked(bool)
 {
-    if (visibleButtonsCount() > 1)
+//    if (visibleButtonsCount() > 1)
+//    {
+//        setChecked(mButtonHash.contains(KWindowSystem::activeWindow()));
+//        setPopupVisible(true);
+//    }
+    if(mPopup->isVisible())
     {
-        setChecked(mButtonHash.contains(KWindowSystem::activeWindow()));
-        setPopupVisible(true);
+        if(HOVER == taskgroupStatus)
+        {
+            taskgroupStatus = NORMAL;
+            return;
+        }
+        else
+        {
+            mPopup->hide();
+            return;
+        }
+    }
+    else
+    {
+        showPreview();
+    }
+    mTaskGroupEvent = OTHEREVENT;
+    if(mTimer->isActive())
+    {
+       mTimer->stop();
     }
 }
 
+
 /************************************************
 
  ************************************************/
@@ -459,10 +513,10 @@ void UKUITaskGroup::recalculateFrameIfVisible()
  ************************************************/
 void UKUITaskGroup::setAutoRotation(bool value, IUKUIPanel::Position position)
 {
-    for (UKUITaskButton *button : qAsConst(mButtonHash))
-        button->setAutoRotation(false, position);
+//    for (QWidget *button : qAsConst(mButtonHash))
+//        button->setAutoRotation(false, position);
 
-    UKUITaskButton::setAutoRotation(value, position);
+    //UKUITaskWidget::setAutoRotation(value, position);
 }
 
 /************************************************
@@ -473,7 +527,7 @@ void UKUITaskGroup::refreshVisibility()
     bool will = false;
     UKUITaskBar const * taskbar = parentTaskBar();
     const int showDesktop = taskbar->showDesktopNum();
-    for(UKUITaskButton * btn : qAsConst(mButtonHash))
+    for(UKUITaskWidget * btn : qAsConst(mButtonHash))
     {
         bool visible = taskbar->isShowOnlyOneDesktopTasks() ? btn->isOnDesktop(0 == showDesktop ? KWindowSystem::currentDesktop() : showDesktop) : true;
         visible &= taskbar->isShowOnlyCurrentScreenTasks() ? btn->isOnCurrentScreen() : true;
@@ -484,7 +538,10 @@ void UKUITaskGroup::refreshVisibility()
 
     bool is = isVisible();
     setVisible(will);
-    regroup();
+    if(!mPopup->isVisible())
+    {
+        regroup();
+    }
 
     if (is != will)
         emit visibilityChanged(will);
@@ -510,6 +567,7 @@ void UKUITaskGroup::setPopupVisible(bool visible, bool fast)
 {
     if (visible && !mPreventPopup && !mSingleButton)
     {
+//        QTimer::singleShot(400, this,SLOT(showPreview()));
         showPreview();
         /* for origin preview
         plugin()->willShowWindow(mPopup);
@@ -527,18 +585,17 @@ void UKUITaskGroup::refreshIconsGeometry()
 {
     QRect rect = geometry();
     rect.moveTo(mapToGlobal(QPoint(0, 0)));
-
     if (mSingleButton)
     {
         refreshIconGeometry(rect);
         return;
     }
 
-    for(UKUITaskButton *but : qAsConst(mButtonHash))
-    {
-        but->refreshIconGeometry(rect);
-        but->setIconSize(QSize(plugin()->panel()->iconSize(), plugin()->panel()->iconSize()));
-    }
+//    for(UKUITaskButton *but : qAsConst(mButtonHash))
+//    {
+//        but->refreshIconGeometry(rect);
+//        but->setIconSize(QSize(plugin()->panel()->iconSize(), plugin()->panel()->iconSize()));
+//    }
 }
 
 /************************************************
@@ -579,8 +636,8 @@ int UKUITaskGroup::recalculateFrameWidth() const
     const QFontMetrics fm = fontMetrics();
     int max = 100 * fm.width (' '); // elide after the max width
     int txtWidth = 0;
-    for (UKUITaskButton *btn : qAsConst(mButtonHash))
-        txtWidth = qMax(fm.width(btn->text()), txtWidth);
+//    for (UKUITaskButton *btn : qAsConst(mButtonHash))
+//        txtWidth = qMax(fm.width(btn->text()), txtWidth);
     return iconSize().width() + qMin(txtWidth, max) + 30/* give enough room to margins and borders*/;
 
 }
@@ -619,25 +676,54 @@ QPoint UKUITaskGroup::recalculateFramePosition()
  ************************************************/
 void UKUITaskGroup::leaveEvent(QEvent *event)
 {
-    setPopupVisible(false);
-    QToolButton::leaveEvent(event);
+    //QTimer::singleShot(300, this,SLOT(mouseLeaveOut()));
+    mTaskGroupEvent = LEAVEEVENT;
+    mEvent = event;
+    if(mTimer->isActive())
+    {
+        mTimer->stop();//stay time is no more than 400 ms need kill timer
+    }
+    else
+    {
+        mTimer->start(300);
+    }
 }
-
 /************************************************
 
  ************************************************/
 void UKUITaskGroup::enterEvent(QEvent *event)
 {
-    QToolButton::enterEvent(event);
+    //QToolButton::enterEvent(event);
+    mTaskGroupEvent = ENTEREVENT;
+    mEvent = event;
+    mTimer->start(400);
+//    if (sDraggging)
+//        return;
+//    if (parentTaskBar()->isShowGroupOnHover())
+//    {
+//        setPopupVisible(true);
+//        parentTaskBar()->setShowGroupOnHover(false);//enter this group other groups will be blocked
+//    }
+//    taskgroupStatus = HOVER;
+//    repaint();
+}
 
+void UKUITaskGroup::handleSavedEvent()
+{
     if (sDraggging)
         return;
     if (parentTaskBar()->isShowGroupOnHover())
     {
         setPopupVisible(true);
     }
+    taskgroupStatus = HOVER;
+    repaint();
+    QToolButton::enterEvent(mEvent);
 }
 
+//void UKUITaskGroup::paintEvent(QPaintEvent *)
+//{
+//}
 /************************************************
 
  ************************************************/
@@ -676,7 +762,7 @@ void UKUITaskGroup::mouseMoveEvent(QMouseEvent* event)
 bool UKUITaskGroup::onWindowChanged(WId window, NET::Properties prop, NET::Properties2 prop2)
 { // returns true if the class is preserved
     bool needsRefreshVisibility{false};
-    QVector<UKUITaskButton *> buttons;
+    QVector<QWidget *> buttons;
     if (mButtonHash.contains(window))
         buttons.append(mButtonHash.value(window));
 
@@ -706,20 +792,20 @@ bool UKUITaskGroup::onWindowChanged(WId window, NET::Properties prop, NET::Prope
             }
         }
 
-        if (prop.testFlag(NET::WMVisibleName) || prop.testFlag(NET::WMName))
-            std::for_each(buttons.begin(), buttons.end(), std::mem_fn(&UKUITaskButton::updateText));
+//        if (prop.testFlag(NET::WMVisibleName) || prop.testFlag(NET::WMName))
+//            std::for_each(buttons.begin(), buttons.end(), std::mem_fn(&UKUITaskButton::updateText));
 
         // XXX: we are setting window icon geometry -> don't need to handle NET::WMIconGeometry
         // Icon of the button can be based on windowClass
-        if (prop.testFlag(NET::WMIcon) || prop2.testFlag(NET::WM2WindowClass))
-            std::for_each(buttons.begin(), buttons.end(), std::mem_fn(&UKUITaskButton::updateIcon));
+//        if (prop.testFlag(NET::WMIcon) || prop2.testFlag(NET::WM2WindowClass))
+//            std::for_each(buttons.begin(), buttons.end(), std::mem_fn(&UKUITaskButton::updateIcon));
 
         if (prop.testFlag(NET::WMState))
         {
             KWindowInfo info{window, NET::WMState};
             if (info.hasState(NET::SkipTaskbar))
                 onWindowRemoved(window);
-            std::for_each(buttons.begin(), buttons.end(), std::bind(&UKUITaskButton::setUrgencyHint, std::placeholders::_1, info.hasState(NET::DemandsAttention)));
+//            std::for_each(buttons.begin(), buttons.end(), std::bind(&UKUITaskButton::setUrgencyHint, std::placeholders::_1, info.hasState(NET::DemandsAttention)));
 
             if (parentTaskBar()->isShowOnlyMinimizedTasks())
             {
@@ -746,9 +832,50 @@ void UKUITaskGroup::groupPopupShown(UKUITaskGroup * const sender)
 
 void UKUITaskGroup::removeWidget()
 {
-    for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
+    mPopup->layout()->removeWidget(mpWidget);
+    QHBoxLayout *hLayout = dynamic_cast<QHBoxLayout*>(mpWidget->layout());
+    QVBoxLayout *vLayout = dynamic_cast<QVBoxLayout*>(mpWidget->layout());
+    if(hLayout != NULL)
     {
-         mPopup->layout()->addWidget(it.value());
+        hLayout->deleteLater();
+        hLayout = NULL;
+    }
+    if(vLayout != NULL)
+    {
+        vLayout->deleteLater();
+        vLayout = NULL;
+    }
+    mpWidget->deleteLater();
+    mpWidget = NULL;
+}
+
+void UKUITaskGroup::setLayOutForPostion()
+{
+    if(plugin()->panel()->isHorizontal())
+    {
+        mpWidget->setLayout(new QHBoxLayout);
+        mpWidget->layout()->setSpacing(3);
+        mpWidget->layout()->setMargin(3);
+    }
+    else
+    {
+        mpWidget->setLayout(new QVBoxLayout);
+        mpWidget->layout()->setSpacing(3);
+        mpWidget->layout()->setMargin(3);
+    }
+}
+
+bool UKUITaskGroup::isSetMaxWindow()
+{
+    int iScreenWidth = QApplication::screens().at(0)->size().width();
+    int iScreenHeight = QApplication::screens().at(0)->size().height();
+    if((iScreenWidth >= SCREEN_MID_WIDTH_SIZE)||((iScreenWidth > SCREEN_MAX_WIDTH_SIZE) && (iScreenHeight > SCREEN_MAX_HEIGHT_SIZE)))
+    {
+        return true;
+    }
+    else
+    {
+        return false;
     }
 }
 
@@ -756,33 +883,175 @@ void UKUITaskGroup::showPreview()
 {
     XImage *img = NULL;
     Display *display = NULL;
+    QPixmap thumbnail;
     XWindowAttributes attr;
-    //removeWidget();
+    int winWidth = 0;
+    int winHeight = 0;
+    int iAverageWidth = calcAverageWidth();
+    int iAverageHeight = calcAverageHeight();
+    /*begin get the winsize*/
+    bool isMaxWinSize = isSetMaxWindow();
+    if(isMaxWinSize)
+    {
+        if(0 == iAverageWidth)
+        {
+
+            winHeight = PREVIEW_WIDGET_MAX_HEIGHT < iAverageHeight?PREVIEW_WIDGET_MAX_HEIGHT:iAverageHeight;
+            winWidth = winHeight*PREVIEW_WIDGET_MAX_WIDTH/PREVIEW_WIDGET_MAX_HEIGHT;
+        }
+        else
+        {
+            winWidth = PREVIEW_WIDGET_MAX_WIDTH < iAverageWidth?PREVIEW_WIDGET_MAX_WIDTH:iAverageWidth;
+            winHeight = winWidth*PREVIEW_WIDGET_MAX_HEIGHT/PREVIEW_WIDGET_MAX_WIDTH;
+        }
+    }
+    else
+    {
+        if(0 == iAverageWidth)
+        {
+            winHeight = PREVIEW_WIDGET_MIN_HEIGHT < iAverageHeight?PREVIEW_WIDGET_MIN_HEIGHT:iAverageHeight;
+            winWidth = winHeight*PREVIEW_WIDGET_MIN_WIDTH/PREVIEW_WIDGET_MIN_HEIGHT;
+        }
+        else
+        {
+            winWidth = PREVIEW_WIDGET_MIN_WIDTH < iAverageWidth?PREVIEW_WIDGET_MIN_WIDTH:iAverageWidth;
+            winHeight = winWidth*PREVIEW_WIDGET_MIN_HEIGHT/PREVIEW_WIDGET_MIN_WIDTH;
+        }
+    }
+    /*end get the winsize*/
+
+    if(mPopup->layout()->count() > 0)
+    {
+        removeWidget();
+    }
+    mpWidget = new QWidget;
+    mpWidget->setAttribute(Qt::WA_TranslucentBackground);
+    setLayOutForPostion();
+    /*begin catch preview picture*/
     for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
     {
+        UKUITaskWidget *btn = it.value();
         display = XOpenDisplay(nullptr);
         XGetWindowAttributes(display, it.key(), &attr);
         img = XGetImage(display, it.key(), 0, 0, attr.width, attr.height, 0xffffffff,ZPixmap);
+        if(img)
+        {
+            thumbnail = qimageFromXImage(img).scaled(THUMBNAIL_WIDTH,THUMBNAIL_HEIGHT,Qt::KeepAspectRatio,Qt::SmoothTransformation);
+            //thumbnail.save(QString("/tmp/picture/%1.png").arg(it.key()));  test picture if correct
+            btn->setThumbNail(thumbnail);
+        }
+        else
+        {
+            QPixmap emptyThumbnail;
+            btn->setThumbNail(emptyThumbnail);
+            qDebug()<<"can not catch picture";
+        }
 
-        QPixmap thumbnail = qimageFromXImage(img).scaled(THUMBNAIL_WIDTH,THUMBNAIL_HEIGHT,Qt::KeepAspectRatio,Qt::FastTransformation);
-        thumbnail.save(QString("/tmp/picture/%1.png").arg(it.key()));
-        //QLabel * label = new QLabel(mPopup); // 创建堆对象
+//        UKUITaskWidget *btn = it.value();
+//        btn->setThumbNail(thumbnail);
+        btn->updateTitle();
+        btn->setFixedSize(winWidth, winHeight);
+        mpWidget->layout()->setContentsMargins(0,0,0,0);
+        mpWidget->layout()->addWidget(btn);
 
-        UKUITaskButton *btn = it.value();
-        btn->setFixedSize(thumbnail.width(),80);
-        btn->setIcon(thumbnail);
-        btn->setIconSize(thumbnail.rect().size());
-
-        btn->setToolButtonStyle(Qt::ToolButtonIconOnly);/*not show title*/
-        //btn->setStyleSheet(QString("border-image:url(/tmp/picture/%1.png)").arg(mButtonHash.begin().key()));
-        mPopup->layout()->addWidget(btn);
-        XDestroyImage(img);
-        XCloseDisplay(display);
+        if(img)
+        {
+           XDestroyImage(img);
+        }
+        if(display)
+        {
+            XCloseDisplay(display);
+        }
     }
+    /*end*/
     plugin()->willShowWindow(mPopup);
-    mPopup->adjustSize();
+    mPopup->layout()->addWidget(mpWidget);
+    adjustPopWindowSize(winWidth, winHeight);
     mPopup->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(QPoint(0,0)), mPopup->size()));
     mPopup->show();
 
    emit popupShown(this);
 }
+
+void UKUITaskGroup::adjustPopWindowSize(int winWidth, int winHeight)
+{
+    if(plugin()->panel()->isHorizontal())
+    {
+        mPopup->setFixedSize(winWidth*mButtonHash.size() + (mButtonHash.size() + 1)*3, winHeight + 6);
+    }
+    else
+    {
+        mPopup->setFixedSize(winWidth + 6,winHeight*mButtonHash.size() + (mButtonHash.size() + 1)*3);
+    }
+    mPopup->adjustSize();
+}
+
+void UKUITaskGroup::timeout()
+{
+
+    if(mTaskGroupEvent == ENTEREVENT)
+    {
+        if(mTimer->isActive())
+        {
+            mTimer->stop();
+        }
+        handleSavedEvent();
+    }
+    else if(mTaskGroupEvent == LEAVEEVENT)
+    {
+        if(mTimer->isActive())
+        {
+            mTimer->stop();
+        }
+        setPopupVisible(false);
+        QToolButton::leaveEvent(mEvent);
+        taskgroupStatus = NORMAL;
+        update();
+    }
+    else
+    {
+        setPopupVisible(false);
+    }
+}
+
+int UKUITaskGroup::calcAverageHeight()
+{
+    if(plugin()->panel()->isHorizontal())
+    {
+        return 0;
+    }
+    else
+    {
+        int iScreenHeight = QApplication::screens().at(0)->size().height();
+        int iMarginHeight = (mButtonHash.size()+1)*3;
+        int iAverageHeight = (iScreenHeight - iMarginHeight)/mButtonHash.size();//calculate average width of window
+        return iAverageHeight;
+    }
+}
+
+int UKUITaskGroup::calcAverageWidth()
+{
+    if(plugin()->panel()->isHorizontal())
+    {
+        int iScreenWidth = QApplication::screens().at(0)->size().width();
+        int iMarginWidth = (mButtonHash.size()+1)*3;
+        int iAverageWidth = (iScreenWidth - iMarginWidth)/mButtonHash.size();//calculate average width of window
+        return iAverageWidth;
+    }
+    else
+    {
+        return 0;
+    }
+}
+
+
+void UKUITaskGroup::showAllWindowByList()
+{
+
+}
+
+
+void UKUITaskGroup::showAllWindowByThumbnail()
+{
+
+}
